@@ -25,12 +25,9 @@ class Command(BaseCommand):
     """
     help = """Discovers Domain Controllers, saves found controller into DomainController model"""
 
-    def handle(self, *args, **kwargs):
+    def handle(self, *args, **kwargs) -> None:
         """
         Perform dns requests
-        :param args:
-        :param kwargs:
-        :return:
         """
-        ip: str = DCList(domain=domain, role=role, name_servers=name_servers).get_available_dc_ip()
+        ip: str = DCList(domain=domain, role=role, nameservers=name_servers).get_available_dc_ip()
         DomainController.set(ip)
